@@ -41,8 +41,8 @@ LXQt Archiver is derived from the following programs:
 * Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
 
 LXQt Archiver は次のプログラムから派生しています:
-* Engrampa of MATE desktop
-* File Roller of Gnome desktop
+* MATE デスクトップの Engrampa
+* Gnome デスクトップの File Roller
 </translation>
     </message>
     <message>
@@ -71,7 +71,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
         <translation>LXQt Archiver
 
-Copyright (C) 2020 the LXQt Team
+Copyright (C) 2020 the LXQt Team 
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -195,7 +195,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../extract.ui" line="36"/>
         <source>Ex&amp;tract selected files</source>
-        <translation>選択されたファイルを展開する(&amp;T)</translation>
+        <translation>選択したファイルを展開する(&amp;T)</translation>
     </message>
     <message>
         <location filename="../extract.ui" line="59"/>
@@ -206,7 +206,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
         <location filename="../extract.ui" line="65"/>
         <source>Re-create folders</source>
         <translatorcomment>動作不明で確認できないため未翻訳</translatorcomment>
-        <translation>フォルダを再作成する</translation>
+        <translation>フォルダーを再作成する</translation>
     </message>
     <message>
         <location filename="../extract.ui" line="72"/>
@@ -313,7 +313,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../mainwindow.ui" line="248"/>
         <source>Alt+Return</source>
-        <translation>Alt+Enter</translation>
+        <translation>Alt+Return</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="257"/>
@@ -532,7 +532,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../mainwindow.cpp" line="852"/>
         <source>No errors have been found.</source>
-        <translation>エラーはありませんでした。</translation>
+        <translation>エラーは見つかりませんでした。</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="830"/>
@@ -813,7 +813,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.<
     <message>
         <location filename="../corestrs.h" line="43"/>
         <source>%d %B %Y, %H:%M</source>
-        <translation>%d %B %Y, %H:%M</translation>
+        <translation>%Y %B %d, %H:%M</translation>
     </message>
     <message>
         <location filename="../corestrs.h" line="47"/>
